<?php
/**
 * Luxury Interior Theme Customizer
 *
 * @package Luxury Interior
 */

get_template_part('/inc/select/category-dropdown-custom-control');

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function luxury_interior_customize_register( $wp_customize ) {

	function luxury_interior_sanitize_phone_number( $phone ) {
		return preg_replace( '/[^\d+]/', '', $phone );
	}

	function luxury_interior_sanitize_checkbox( $checked ) {
		// Boolean check.
		return ( ( isset( $checked ) && true == $checked ) ? true : false );
	}

	$wp_customize->get_setting( 'blogname' )->transport         = 'postMessage';
	$wp_customize->get_setting( 'blogdescription' )->transport  = 'postMessage';

	//Theme Options
	$wp_customize->add_panel( 'luxury_interior_panel_area', array(
		'priority' => 10,
		'capability' => 'edit_theme_options',
		'title' => __( 'Theme Options Panel', 'luxury-interior' ),
	) );
	
	// Header Section
	$wp_customize->add_section('luxury_interior_header_section', array(
        'title' => __('Manage Header Section', 'luxury-interior'),
        'priority' => null,
		'panel' => 'luxury_interior_panel_area',
 	));

	$wp_customize->add_setting('luxury_interior_email_address',array(
		'default' => '',
		'sanitize_callback' => 'sanitize_email',
		'capability' => 'edit_theme_options',
	));
	$wp_customize->add_control( 'luxury_interior_email_address', array(
	   'settings' => 'luxury_interior_email_address',
	   'section'   => 'luxury_interior_header_section',
	   'label' => __('Add Email Address', 'luxury-interior'),
	   'type'      => 'text'
	));

	$wp_customize->add_setting('luxury_interior_fb_link',array(
		'default' => '',
		'sanitize_callback' => 'esc_url_raw',
		'capability' => 'edit_theme_options',
	));
	$wp_customize->add_control( 'luxury_interior_fb_link', array(
	   'settings' => 'luxury_interior_fb_link',
	   'section'   => 'luxury_interior_header_section',
	   'label' => __('Facebook Link', 'luxury-interior'),
	   'type'      => 'url'
	));

	$wp_customize->add_setting('luxury_interior_twitt_link',array(
		'default' => '',
		'sanitize_callback' => 'esc_url_raw',
		'capability' => 'edit_theme_options',
	));
	$wp_customize->add_control( 'luxury_interior_twitt_link', array(
	   'settings' => 'luxury_interior_twitt_link',
	   'section'   => 'luxury_interior_header_section',
	   'label' => __('Twitter Link', 'luxury-interior'),
	   'type'      => 'url'
	));

	$wp_customize->add_setting('luxury_interior_linked_link',array(
		'default' => '',
		'sanitize_callback' => 'esc_url_raw',
		'capability' => 'edit_theme_options',
	));
	$wp_customize->add_control( 'luxury_interior_linked_link', array(
	   'settings' => 'luxury_interior_linked_link',
	   'section'   => 'luxury_interior_header_section',
	   'label' => __('Linkdin Link', 'luxury-interior'),
	   'type'      => 'url'
	));

	$wp_customize->add_setting('luxury_interior_insta_link',array(
		'default' => '',
		'sanitize_callback' => 'esc_url_raw',
		'capability' => 'edit_theme_options',
	));
	$wp_customize->add_control( 'luxury_interior_insta_link', array(
	   'settings' => 'luxury_interior_insta_link',
	   'section'   => 'luxury_interior_header_section',
	   'label' => __('Instagram Link', 'luxury-interior'),
	   'type'      => 'url'
	));

	$wp_customize->add_setting('luxury_interior_youtube_link',array(
		'default' => '',
		'sanitize_callback' => 'esc_url_raw',
		'capability' => 'edit_theme_options',
	));
	$wp_customize->add_control( 'luxury_interior_youtube_link', array(
	   'settings' => 'luxury_interior_youtube_link',
	   'section'   => 'luxury_interior_header_section',
	   'label' => __('Youtube Link', 'luxury-interior'),
	   'type'      => 'url'
	));

	// Home Category Dropdown Section
	$wp_customize->add_section('luxury_interior_one_cols_section',array(
		'title'	=> __('Manage Slider','luxury-interior'),
		'description'	=> __('Select Category from the Dropdowns for slider, Also use the given image dimension (1600 x 850).','luxury-interior'),
		'priority'	=> null,
		'panel' => 'luxury_interior_panel_area'
	));

	// Add a category dropdown Slider Coloumn
	$wp_customize->add_setting( 'luxury_interior_slidersection', array(
		'default'	=> '0',	
		'sanitize_callback'	=> 'absint'
	) );
	$wp_customize->add_control( new luxury_interior_Category_Dropdown_Custom_Control( $wp_customize, 'luxury_interior_slidersection', array(
		'section' => 'luxury_interior_one_cols_section',
		'settings'   => 'luxury_interior_slidersection',
	) ) );

	$wp_customize->add_setting('luxury_interior_button_text',array(
		'default' => 'Hire Me',
		'sanitize_callback' => 'sanitize_text_field',
		'capability' => 'edit_theme_options',
	));
	$wp_customize->add_control( 'luxury_interior_button_text', array(
	   'settings' => 'luxury_interior_button_text',
	   'section'   => 'luxury_interior_one_cols_section',
	   'label' => __('Add Button Text', 'luxury-interior'),
	   'type'      => 'text'
	));
	
	//Hide Section
	$wp_customize->add_setting('luxury_interior_hide_categorysec',array(
		'default' => true,
		'sanitize_callback' => 'luxury_interior_sanitize_checkbox',
		'capability' => 'edit_theme_options',
	));	 

	$wp_customize->add_control( 'luxury_interior_hide_categorysec', array(
	   'settings' => 'luxury_interior_hide_categorysec',
	   'section'   => 'luxury_interior_one_cols_section',
	   'label'     => __('Uncheck To Enable This Section','luxury-interior'),
	   'type'      => 'checkbox'
	));
	
	// Services Section 
	$wp_customize->add_section('luxury_interior_below_slider_section', array(
		'title'	=> __('Manage Services Section','luxury-interior'),
		'description'	=> __('Select Pages from the dropdown for Services.','luxury-interior'),
		'priority'	=> null,
		'panel' => 'luxury_interior_panel_area',
	));

	$wp_customize->add_setting('luxury_interior_headingtext1',array(
		'default' => '',
		'sanitize_callback' => 'sanitize_text_field',
		'capability' => 'edit_theme_options',
	));
	$wp_customize->add_control( 'luxury_interior_headingtext1', array(
	   'settings' => 'luxury_interior_headingtext1',
	   'section'   => 'luxury_interior_below_slider_section',
	   'label' => __('Add Heading 1', 'luxury-interior'),
	   'type'      => 'text'
	));

	$wp_customize->add_setting('luxury_interior_headingtext2',array(
		'default' => '',
		'sanitize_callback' => 'sanitize_text_field',
		'capability' => 'edit_theme_options',
	));
	$wp_customize->add_control( 'luxury_interior_headingtext2', array(
	   'settings' => 'luxury_interior_headingtext2',
	   'section'   => 'luxury_interior_below_slider_section',
	   'label' => __('Add Heading 2', 'luxury-interior'),
	   'type'      => 'text'
	));

	$wp_customize->add_setting('luxury_interior_headingtext_para',array(
		'default' => '',
		'sanitize_callback' => 'sanitize_text_field',
		'capability' => 'edit_theme_options',
	));
	$wp_customize->add_control( 'luxury_interior_headingtext_para', array(
	   'settings' => 'luxury_interior_headingtext_para',
	   'section'   => 'luxury_interior_below_slider_section',
	   'label' => __('Add Heading Content', 'luxury-interior'),
	   'type'      => 'text'
	));

	// Add a category dropdown Slider Coloumn
	$wp_customize->add_setting( 'luxury_interior_services_cat', array(
		'default'	=> '0',	
		'sanitize_callback'	=> 'absint'
	) );
	$wp_customize->add_control( new luxury_interior_Category_Dropdown_Custom_Control( $wp_customize, 'luxury_interior_services_cat', array(
		'section' => 'luxury_interior_below_slider_section',
		'settings'   => 'luxury_interior_services_cat',
	) ) );

	$wp_customize->add_setting('luxury_interior_disabled_pgboxes',array(
		'default' => true,
		'sanitize_callback' => 'luxury_interior_sanitize_checkbox',
		'capability' => 'edit_theme_options',
	));
	
	$wp_customize->add_control( 'luxury_interior_disabled_pgboxes', array(
	   'settings' => 'luxury_interior_disabled_pgboxes',
	   'section'   => 'luxury_interior_below_slider_section',
	   'label'     => __('Uncheck To Enable This Section','luxury-interior'),
	   'type'      => 'checkbox'
	));

	// Footer Section 
	$wp_customize->add_section('luxury_interior_footer', array(
		'title'	=> __('Manage Footer Section','luxury-interior'),
		'priority'	=> null,
		'panel' => 'luxury_interior_panel_area',
	));

	$wp_customize->add_setting('luxury_interior_copyright_line',array(
		'sanitize_callback' => 'sanitize_text_field',
	));	
	$wp_customize->add_control( 'luxury_interior_copyright_line', array(
	   'section' 	=> 'luxury_interior_footer',
	   'label'	 	=> __('Copyright Line','luxury-interior'),
	   'type'    	=> 'text',
	   'priority' 	=> null,
    ));

	//Color
	$wp_customize->add_setting('luxury_interior_color_scheme_one',array(
		'default' => '#fdcf55',
		'sanitize_callback' => 'sanitize_hex_color',
	));
    $wp_customize->add_control( 
	    new WP_Customize_Color_Control( 
	    $wp_customize, 
	    'luxury_interior_color_scheme_one', 
	    array(
	        'label'      => __( 'Color Scheme', 'luxury-interior' ),
	        'section'    => 'colors',
	        'settings'   => 'luxury_interior_color_scheme_one',
	    ) )
	);
}
add_action( 'customize_register', 'luxury_interior_customize_register' );

/**
 * Binds JS handlers to make Theme Customizer preview reload changes asynchronously.
 */
function luxury_interior_customize_preview_js() {
	wp_enqueue_script( 'luxury_interior_customizer', esc_url(get_template_directory_uri()) . '/js/customize-preview.js', array( 'customize-preview' ), '20161510', true );
}
add_action( 'customize_preview_init', 'luxury_interior_customize_preview_js' );